Raleway Fonts
====================

## Current Status
- Version 3.001 is the latest stable version.
- Version 4.xxx is an ongoing migration to Glyphs and Vietnamese and Cyrillic extension, but is still a work in progress.

## Description

Raleway is an elegant sans-serif typeface family.

Initially designed by [Matt McInerney](http://blog.matt.cc/) as a [single thin weight](https://github.com/theleagueof/raleway), it was expanded into a 9 weight family by Pablo Impallari and Rodrigo Fuenzalida in 2012 and iKerned by Igino Marini. In 2013 the Italics where added.

It is a display face and the download features both old style and lining numerals, standard and discretionary ligatures, a pretty complete set of diacritics, as well as a stylistic alternate inspired by more geometric sans-serif typefaces than its neo-grotesque inspired default character set.

It also has a sister display family, Raleway Dots.

#### The characters set has been expanded to cover 105 Latin languages: 

Afar, Afrikaans, Albanian, Azerbaijani, Basque, Belarusian, Bislama, Bosnian, Breton, Catalan, Chamorro, Chichewa, Comorian, Croatian, Czech, Danish, Dutch, English, Esperanto, Estonian, Faroese, Fijian, Filipino/Tagalog, Finnish, Flemish, French, Gaelic (Irish / Manx / Scottish), Gagauz, German, Gikuyu, Gilbertese/Kiribati, Greenlandic, Guarani, Haitian_Creole, Hawaiian, Hungarian, Icelandic, Igo/Igbo, Indonesian, Irish, Italian, Javanese, Kashubian, Kinyarwanda, Kirundi, Latin, Latvian, Lithuanian, Luba/Ciluba/Kasai, Luxembourgish, Malagasy, Malay, Maltese, Maori, Marquesan, Marshallese, Moldovan/Moldovian/Romanian, Montenegrin, Nauruan, Ndebele, Norwegian, Oromo, Palauan/Belauan, Polish, Portuguese, Quechua, Romanian, Romansh, Sami, Samoan, Sango, Serbian, Sesotho, Setswana/Sitswana/Tswana, Seychellois_Creole, SiSwati/Swati/Swazi, Silesian, Slovak, Slovenian, Somali, Sorbian, Sotho, Spanish, Swahili, Swedish, Tahitian, Tetum, Tok_Pisin, Tongan, Tsonga, Tswana, Tuareg/Berber, Turkish, Turkmen, Tuvaluan, Uzbek/Usbek, Vietnamese, Wallisian, Walloon, Welsh, Xhosa, Yoruba, Zulu.

#### Vietnamese

Native Vietnamese designer Nhung Nguyen (@crystaltype) has added support for Vietnamese to version 4.0000. 

#### 60 Cyrillic languages | Кириллица

Raleway Fonts v.3.000 included core Cyrillic support for 17 languages in Roman styles. Core Cyrillic glyphs were drawn by Pablo Impallari in 2013.  

In August-September 2016 (Raleway v.4.000) existing Cyrillic was redrawn and expanded for both Roman and Italic by Alexei Vanyashin and Ivan Petrov ([Cyreal](http://cyreal.org)) to support 60 Cyrillic languages: 

Adyghe, Agul, Altay, Avar, Azerbaijani (Cyrillic), Balkar, Bashkir, Belarusian (Cyrillic), Bosnian (Cyrillic), Bulgarian, Buryat, Chechen, Chuvash, Crimean Tatar (Cyrillic), Croatian (Cyrillic), Dargin, Dungan, Erzya, Gagauz (Cyrillic), Ingush, Kabardian, Kalmyk, Karachay, Karakalpak, Kazakh, Khakas (Cyrillic), Khinalugh, Komi, Kumyk, Kurdish (Cyrillic), Kyrgyz (Cyrillic), Lak, Lezgian, Macedonian, Mari (Hill and Meadow), Moksha, Moldovan (Cyrillic), Mongolian (Cyrillic), Montenigrin, Nanai, Nogai, Ossetian, Russian, Rusyn, Rutul, Sakha/Yakut, Serbian (Cyrillic), Tabasaran, Tajik, Talysh (Cyrillic), Tat, Tatar, Turkmen, Tuvan, Udi, Udmurt, Ukrainian, Uyghur (Cyrillic), Uzbek (Cyrillic), Yukaghir (Northern and Southern).

Localised variants are available for Bulgarian, Serbian, Macedonian, Chuvash, and Bashkir languages.

Includes currencies: ₮, ₴, ₸, ₽.

#### Copyright

Copyright (c) 2010, Matt McInerney (matt@pixelspread.com),
Copyright (c) 2011, Pablo Impallari (www.impallari.com|impallari@gmail.com),
Copyright (c) 2011, Rodrigo Fuenzalida (www.rfuenzalida.com|hello@rfuenzalida.com), with Reserved Font Name Raleway

#### Font Samples

![Raleway font sample](documents/raleway-promo.jpg)

#### License

This Font Software is licensed under the SIL Open Font License, Version 1.1.
This license is copied below, and is also available with a FAQ at:
http://scripts.sil.org/OFL


#### Links
* [Raleway on Google Fonts](https://fonts.google.com/specimen/Raleway)
* [Impallari.com](http://www.impallari.com)
